aboutsummaryrefslogtreecommitdiff
path: root/linux-core/intel_modes.c
diff options
context:
space:
mode:
authorDave Airlie <airlied@redhat.com>2008-05-30 15:03:12 +1000
committerDave Airlie <airlied@redhat.com>2008-05-30 15:10:04 +1000
commit9d38448ed33aaff324cc4bbe1e0878593e97d07d (patch)
treef6e1dcfb4d2fbdca3db979580ecce800d737feea /linux-core/intel_modes.c
parent6aeef92c0cad784a5019ea90d97ab81f4e51fdd9 (diff)
modesetting: the great renaming.
Okay we have crtc, encoder and connectors. No more outputs exposed beyond driver internals I've broken intel tv connector stuff. Really for TV we should have one TV connector, with a sub property for the type of signal been driven over it
Diffstat (limited to 'linux-core/intel_modes.c')
-rw-r--r--linux-core/intel_modes.c16
1 files changed, 7 insertions, 9 deletions
diff --git a/linux-core/intel_modes.c b/linux-core/intel_modes.c
index 8e9a506a..79be3575 100644
--- a/linux-core/intel_modes.c
+++ b/linux-core/intel_modes.c
@@ -13,9 +13,8 @@
* intel_ddc_probe
*
*/
-bool intel_ddc_probe(struct drm_output *output)
+bool intel_ddc_probe(struct intel_output *intel_output)
{
- struct intel_output *intel_output = to_intel_output(output);
u8 out_buf[] = { 0x0, 0x0};
u8 buf[2];
int ret;
@@ -43,20 +42,19 @@ bool intel_ddc_probe(struct drm_output *output)
/**
* intel_ddc_get_modes - get modelist from monitor
* @output: DRM output device to use
*
* Fetch the EDID information from @output using the DDC bus.
*/
-int intel_ddc_get_modes(struct drm_output *output)
+int intel_ddc_get_modes(struct intel_output *intel_output)
{
- struct intel_output *intel_output = to_intel_output(output);
struct edid *edid;
int ret = 0;
- edid = drm_get_edid(output, &intel_output->ddc_bus->adapter);
+ edid = drm_get_edid(&intel_output->base, &intel_output->ddc_bus->adapter);
if (edid) {
- drm_mode_output_update_edid_property(output, edid);
- ret = drm_add_edid_modes(output, edid);
+ drm_mode_connector_update_edid_property(&intel_output->base, edid);
+ ret = drm_add_edid_modes(&intel_output->base, edid);
kfree(edid);
}
return ret;
@@ -43,20 +42,19 @@ bool intel_ddc_probe(struct drm_output *output)
/**
* intel_ddc_get_modes - get modelist from monitor
- * @output: DRM output device to use
+ * @connector: DRM connector device to use
*
@@ -43,20 +42,19 @@ bool intel_ddc_probe(struct drm_output *output)
*
- * Fetch the EDID information from @output using the DDC bus.
+ * Fetch the EDID information from @connector using the DDC bus.
*/